@@ -69,19 +69,56 @@ test_type test_array[]={
 
   {ACT_DELETE,"","",0,ASN1_ELEMENT_NOT_FOUND},
 
-  /* Test: OID and TIME */
+  /* Test: OID */
+  {ACT_CREATE,"TEST_TREE.OidTest",0,0,ASN1_SUCCESS},
+  {ACT_READ_LENGTH,"oid",NULL,9,ASN1_MEM_ERROR},
+  {ACT_READ,"oid","2.5.29.2",9,ASN1_SUCCESS},
+  {ACT_WRITE,"oid","1.2.3.4",0,ASN1_SUCCESS},
+  {ACT_WRITE,"oid2","2.5.29.1",0,ASN1_SUCCESS},
+  {ACT_WRITE,"oid3","1.2.29.2",0,ASN1_SUCCESS},
+  {ACT_ENCODING_LENGTH,"",0,7,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,6,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,7,ASN1_SUCCESS},
+  {ACT_PRINT_DER,0,0,0,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
+  {ACT_CREATE,"TEST_TREE.OidTest",0,0,ASN1_SUCCESS},
+  {ACT_DECODING,0,0,0,ASN1_SUCCESS},
+  {ACT_DECODING_START_END,"oid","START",2,ASN1_SUCCESS},
+  {ACT_DECODING_START_END,"oid","END",6,ASN1_SUCCESS},
+  {ACT_DECODING_START_END,"","START",0,ASN1_SUCCESS},
+  {ACT_DECODING_START_END,"","END",6,ASN1_SUCCESS},
+  {ACT_READ,"oid2","2.5.29.1",9,ASN1_SUCCESS},
+  {ACT_READ,"oid3","1.2.29.2",9,ASN1_SUCCESS},
+  {ACT_WRITE,"oid","1.2.3.4",0,ASN1_SUCCESS},
+  {ACT_VISIT,"","",ASN1_PRINT_ALL,ASN1_SUCCESS},
+  {ACT_DELETE,"","",0,ASN1_SUCCESS},
+
+  /* Test: ENCODING_LENGTH and READ_LEN */
   {ACT_CREATE,"TEST_TREE.OidAndTimeTest",0,0,ASN1_SUCCESS},
   {ACT_WRITE,"oid","1.2.3.4",0,ASN1_SUCCESS},
   {ACT_WRITE,"time1","9801011200Z",1,ASN1_SUCCESS},
   {ACT_WRITE,"time2","2001010112001.12-0700",1,ASN1_SUCCESS},
   {ACT_WRITE,"oct","ABCD",4,ASN1_SUCCESS},
+  {ACT_WRITE,"bol","TRUE",1,ASN1_SUCCESS},
+  {ACT_WRITE,"enum","2",0,ASN1_SUCCESS},
+  {ACT_WRITE,"bit","1\xC0",10,ASN1_SUCCESS},
+  {ACT_WRITE,"any","\x30\x01\x01",3,ASN1_SUCCESS},
+  {ACT_WRITE,"set","NEW",0,ASN1_SUCCESS},
+  {ACT_WRITE,"set.?LAST","10",0,ASN1_SUCCESS},
+  {ACT_WRITE,"set","NEW",0,ASN1_SUCCESS},
+  {ACT_WRITE,"set.?LAST","1",0,ASN1_SUCCESS},
+  {ACT_WRITE,"gen","Prova",5,ASN1_SUCCESS},
   {ACT_READ_LENGTH,"oid",NULL,8,ASN1_MEM_ERROR},
   {ACT_READ_LENGTH,"time1",NULL,12,ASN1_MEM_ERROR},
   {ACT_READ_LENGTH,"time2",NULL,22,ASN1_MEM_ERROR},
   {ACT_READ_LENGTH,"oct",NULL,4,ASN1_MEM_ERROR},
-  {ACT_ENCODING_LENGTH,"",0,49,ASN1_MEM_ERROR},
-  {ACT_ENCODING,"",0,48,ASN1_MEM_ERROR},
-  {ACT_ENCODING,"",0,200,ASN1_SUCCESS},
+  {ACT_READ_LENGTH,"bol",NULL,5,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"enum",NULL,1,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"any",NULL,3,ASN1_MEM_ERROR},
+  {ACT_READ_LENGTH,"gen",NULL,5,ASN1_MEM_ERROR},
+  {ACT_ENCODING_LENGTH,"",0,79,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,78,ASN1_MEM_ERROR},
+  {ACT_ENCODING,"",0,79,ASN1_SUCCESS},
   {ACT_PRINT_DER,0,0,0,ASN1_SUCCESS},
   {ACT_DELETE,"","",0,ASN1_SUCCESS},
   {ACT_CREATE,"TEST_TREE.OidAndTimeTest",0,0,ASN1_SUCCESS},
@@ -280,7 +317,7 @@ main(int argc,char *argv[])
   printf(    "/****************************************/\n\n");
 
   /* Check version */
-  if(asn1_check_version("0.2.2")==NULL)
+  if(asn1_check_version("0.2.4")==NULL)
     printf("\nLibrary version check ERROR:\n actual version: %s\n\n",asn1_check_version(NULL));
 
   if(1)
